@@ -11,12 +11,12 @@ from requests.auth import HTTPBasicAuth
 import yaml
 import time
 
-VERSION = '0.1.4'
+VERSION = '0.1.5'
 
-default_backliftURL = 'http://backlift.com/'
+default_backliftURL = 'https://www.backlift.com/'
 backlift_configfile = '.backlift'
 backlift_email = 'support@backlift.com'
-backlift_dir = '.backlift'
+backlift_dir = '.backlift_env'
 
 # maxfiles is set to a few less than the system limit. 
 maxfiles = resource.getrlimit(resource.RLIMIT_NOFILE)[0] - 6
@@ -200,7 +200,8 @@ def read_api_key():
 def register_key(key):
     # import pdb; pdb.set_trace()
     try:
-        r = requests.post(backliftURL_registerkey, params={'access_key': key})
+        r = requests.post(backliftURL_registerkey, 
+                          params={'access_key': key}, verify=False)
         check_response(r)
     except requests.exceptions.ConnectionError:
         fail(ERR_SERVER)
@@ -210,7 +211,7 @@ def create_app(api_key):
     try:
         # import pdb; pdb.set_trace()
         r = requests.post(backliftURL_createapp, 
-                          auth=HTTPBasicAuth('api', api_key))
+                          auth=HTTPBasicAuth('api', api_key), verify=False)
         check_response(r)
 
         r = json.loads(r.text)
@@ -228,7 +229,8 @@ def download_template_files(path, template, api_key, params=None):
         # import pdb; pdb.set_trace()
 
         manifest_url = os.path.join(backliftURL_templatefiles, template)
-        r = requests.get(manifest_url, auth=HTTPBasicAuth('api', api_key))
+        r = requests.get(manifest_url, 
+                         auth=HTTPBasicAuth('api', api_key), verify=False)
         check_response(r)
 
         r = json.loads(r.text)
@@ -239,7 +241,7 @@ def download_template_files(path, template, api_key, params=None):
 
                 file_url = os.path.join(backliftURL_templatefiles, template, f)
                 r = requests.get(file_url, params=params, 
-                                 auth=HTTPBasicAuth('api', api_key))
+                                 auth=HTTPBasicAuth('api', api_key), verify=False)
                 check_response(r)
 
                 filepath = os.path.abspath(os.path.join(path, f))
@@ -258,7 +260,7 @@ def download_template_files(path, template, api_key, params=None):
 def upload_files(id, files, api_key):
     try:
         r = requests.put(backliftURL_upload % id, files=files,
-                         auth=HTTPBasicAuth('api', api_key))
+                         auth=HTTPBasicAuth('api', api_key), verify=False)
 
         for filekey, filedata in files.items():
             filedata[1].close()
@@ -316,12 +318,13 @@ def create(path, name='', template='blank'):
 
 
 def init(path):
-    api_key = read_api_key()
-    create(path, api_key)
+    create(path)
 
 
 def push(path, skip_hidden):
 
+    # import pdb; pdb.set_trace()
+
     api_key = read_api_key()
 
     # scan path for files to upload 
